@@ -27,9 +27,14 @@
 //!     Ok(())
 //! }
 //! ```
+//!
+//! # Available Services
+//!
+//! - [AWS SigV4][crate::services::aws::v4::Signer] for AWS services like S3.
+//! - [Azure Storage][crate::services::azure::storage::Signer] for Azure Storage services like Azure Blob Service.
 pub mod request;
 pub mod services;
 
 pub(crate) mod dirs;
 pub(crate) mod hash;
-pub(crate) mod time;
+pub mod time;
