@@ -1,29 +1,14 @@
 // Headers used in aws services.
-#[allow(dead_code)]
 pub const X_AMZ_CONTENT_SHA_256: &str = "x-amz-content-sha256";
-#[allow(dead_code)]
 pub const X_AMZ_DATE: &str = "x-amz-date";
-#[allow(dead_code)]
 pub const X_AMZ_SECURITY_TOKEN: &str = "x-amz-security-token";
-#[allow(dead_code)]
-pub const X_AMZ_USER_AGENT: &str = "x-amz-user-agent";
 
 // Env values used in aws services.
-#[allow(dead_code)]
 pub const AWS_ACCESS_KEY_ID: &str = "AWS_ACCESS_KEY_ID";
-#[allow(dead_code)]
 pub const AWS_SECRET_ACCESS_KEY: &str = "AWS_SECRET_ACCESS_KEY";
-#[allow(dead_code)]
 pub const AWS_REGION: &str = "AWS_REGION";
-#[allow(dead_code)]
 pub const AWS_CONFIG_FILE: &str = "AWS_CONFIG_FILE";
-#[allow(dead_code)]
 pub const AWS_SHARED_CREDENTIALS_FILE: &str = "AWS_SHARED_CREDENTIALS_FILE";
-#[allow(dead_code)]
-pub const AWS_PROFILE: &str = "AWS_PROFILE";
-#[allow(dead_code)]
 pub const AWS_WEB_IDENTITY_TOKEN_FILE: &str = "AWS_WEB_IDENTITY_TOKEN_FILE";
-#[allow(dead_code)]
 pub const AWS_ROLE_ARN: &str = "AWS_ROLE_ARN";
-#[allow(dead_code)]
 pub const AWS_ROLE_SESSION_NAME: &str = "AWS_ROLE_SESSION_NAME";
