@@ -1,3 +1,5 @@
+//! Loader is used to load credential or region from env.
+//!
 //! - Environment variables: AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, and AWS_REGION
 //! - The default credentials files located in ~/.aws/config and ~/.aws/credentials (location can vary per platform)
 //! - Web Identity Token credentials from the environment or container (including EKS)
@@ -15,8 +17,7 @@ use reqwest::Url;
 
 use super::credential::Credential;
 use crate::dirs::expand_homedir;
-use crate::time;
-use crate::time::ISO8601_WITH_SEPERATOR;
+use crate::time::parse_rfc3339;
 
 /// Loader trait will try to load credential and region from different sources.
 #[async_trait]
@@ -265,7 +266,7 @@ impl CredentialLoad for WebIdentityTokenLoader {
                         "Expiration" => {
                             let text = n.text().expect("Expiration must be exist");
 
-                            builder.expires_in(time::parse_utc(text, ISO8601_WITH_SEPERATOR)?);
+                            builder.expires_in(parse_rfc3339(text)?);
                         }
                         _ => {}
                     }
