@@ -3,7 +3,6 @@ use std::fmt::{Debug, Display, Formatter};
 use std::mem;
 use std::str::FromStr;
 use std::sync::Arc;
-use std::time::SystemTime;
 
 use anyhow::{anyhow, Result};
 use http::header::HeaderName;
@@ -12,15 +11,12 @@ use log::debug;
 use tokio::sync::RwLock;
 
 use super::credential::Credential;
-use super::loader::{
-    CredentialLoad, CredentialLoadChain, EnvLoader, ProfileLoader, RegionLoad, RegionLoadChain,
-    WebIdentityTokenLoader,
-};
+use super::loader::*;
 use crate::hash::{hex_hmac_sha256, hex_sha256, hmac_sha256};
 use crate::request::SignableRequest;
-use crate::time::{self, DATE, ISO8601};
+use crate::time::{self, format_date, format_iso8601, DateTime};
 
-/// Builder for Signer.
+/// Builder for `Signer`.
 #[derive(Default)]
 pub struct Builder {
     service: Option<String>,
@@ -32,7 +28,7 @@ pub struct Builder {
 
     allow_anonymous: bool,
 
-    time: Option<SystemTime>,
+    time: Option<DateTime>,
 }
 
 impl Builder {
@@ -107,7 +103,7 @@ impl Builder {
     /// We should always take current time to sign requests.
     /// Only use this function for testing.
     #[cfg(test)]
-    pub fn time(&mut self, time: SystemTime) -> &mut Self {
+    pub fn time(&mut self, time: DateTime) -> &mut Self {
         self.time = Some(time);
         self
     }
@@ -120,7 +116,7 @@ impl Builder {
             .service
             .as_ref()
             .ok_or_else(|| anyhow!("service is required"))?;
-        debug!("service: {:?}", service);
+        debug!("signer: service: {:?}", service);
 
         let credential = if self.credential.is_valid() {
             Some(self.credential.clone())
@@ -135,7 +131,7 @@ impl Builder {
 
             self.credential_load.load_credential().await?
         };
-        debug!("credential has been set to: {:?}", &credential);
+        debug!("signer credential: {:?}", &credential);
 
         let region = match &self.region {
             Some(region) => region.to_string(),
@@ -153,7 +149,7 @@ impl Builder {
                     .ok_or_else(|| anyhow!("region is required"))?
             }
         };
-        debug!("region has been set to: {}", &region);
+        debug!("signer region: {}", &region);
 
         Ok(Signer {
             service: service.to_string(),
@@ -178,7 +174,7 @@ pub struct Signer {
     /// Allow anonymous request if credential is not loaded.
     allow_anonymous: bool,
 
-    time: Option<SystemTime>,
+    time: Option<DateTime>,
 }
 
 impl Signer {
@@ -225,7 +221,7 @@ impl Signer {
         // Scope: "20220313/<region>/<service>/aws4_request"
         let scope = format!(
             "{}/{}/{}/aws4_request",
-            time::format(canonical_req.time, DATE),
+            format_date(canonical_req.time),
             self.region,
             self.service
         );
@@ -242,7 +238,7 @@ impl Signer {
 
             let mut f = String::new();
             writeln!(f, "AWS4-HMAC-SHA256")?;
-            writeln!(f, "{}", time::format(canonical_req.time, ISO8601))?;
+            writeln!(f, "{}", format_iso8601(canonical_req.time))?;
             writeln!(f, "{}", &scope)?;
             write!(f, "{}", &encoded_req)?;
             f
@@ -268,10 +264,10 @@ impl Signer {
     }
 
     /// Apply signed results to requests.
-    pub fn apply(&self, sig: &SignedOutput, req: &mut impl SignableRequest) -> Result<()> {
+    pub fn apply(&self, req: &mut impl SignableRequest, sig: &SignedOutput) -> Result<()> {
         req.apply_header(
             HeaderName::from_static(super::constants::X_AMZ_DATE),
-            &time::format(sig.signed_time, ISO8601),
+            &format_iso8601(sig.signed_time),
         )?;
         req.apply_header(
             HeaderName::from_static(super::constants::X_AMZ_CONTENT_SHA_256),
@@ -319,7 +315,7 @@ impl Signer {
     ///         .build()
     ///         .await?;
     ///     // Construct request
-    ///     let url = Url::parse( "https://s3.amazonaws.com/testbucket")?;
+    ///     let url = Url::parse("https://s3.amazonaws.com/testbucket")?;
     ///     let mut req = reqwest::Request::new(http::Method::GET, url);
     ///     // Signing request with Signer
     ///     signer.sign(&mut req).await?;
@@ -332,7 +328,7 @@ impl Signer {
     pub async fn sign(&self, req: &mut impl SignableRequest) -> Result<()> {
         if let Some(cred) = self.credential().await? {
             let sig = self.calculate(req, &cred)?;
-            return self.apply(&sig, req);
+            return self.apply(req, &sig);
         }
 
         if self.allow_anonymous {
@@ -361,7 +357,7 @@ struct CanonicalRequest<'a> {
     params: Option<String>,
     headers: http::HeaderMap,
 
-    time: SystemTime,
+    time: DateTime,
     signed_headers: Vec<HeaderName>,
     content_sha256: &'a str,
 }
@@ -369,10 +365,10 @@ struct CanonicalRequest<'a> {
 impl<'a> CanonicalRequest<'a> {
     pub fn from<'b>(
         req: &'b impl SignableRequest,
-        time: Option<SystemTime>,
+        time: Option<DateTime>,
         cred: &'b Credential,
     ) -> Result<CanonicalRequest<'b>> {
-        let now = time.unwrap_or_else(SystemTime::now);
+        let now = time.unwrap_or_else(time::now);
 
         let (signed_headers, canonical_headers) = Self::headers(req, now, cred)?;
 
@@ -394,7 +390,7 @@ impl<'a> CanonicalRequest<'a> {
 
     pub fn headers(
         req: &impl SignableRequest,
-        now: SystemTime,
+        now: DateTime,
         cred: &Credential,
     ) -> Result<(Vec<HeaderName>, HeaderMap)> {
         let mut canonical_headers = HeaderMap::with_capacity(req.headers().len());
@@ -419,8 +415,8 @@ impl<'a> CanonicalRequest<'a> {
             .get(HeaderName::from_static(super::constants::X_AMZ_DATE))
             .is_none()
         {
-            let date_header = HeaderValue::try_from(time::format(now, ISO8601))
-                .expect("date is valid header value");
+            let date_header =
+                HeaderValue::try_from(format_iso8601(now)).expect("date is valid header value");
             canonical_headers.insert(
                 HeaderName::from_static(super::constants::X_AMZ_DATE),
                 date_header,
@@ -534,7 +530,7 @@ impl<'a> Display for CanonicalRequest<'a> {
 pub struct SignedOutput {
     access_key_id: String,
     security_token: Option<String>,
-    signed_time: SystemTime,
+    signed_time: DateTime,
     signed_scope: String,
     signed_headers: Vec<HeaderName>,
     signature: String,
@@ -558,11 +554,11 @@ fn normalize_header_value(header_value: &HeaderValue) -> HeaderValue {
     HeaderValue::from_bytes(&bs[starting_index..ending_index]).expect("invalid header value")
 }
 
-fn generate_signing_key(secret: &str, time: SystemTime, region: &str, service: &str) -> Vec<u8> {
+fn generate_signing_key(secret: &str, time: DateTime, region: &str, service: &str) -> Vec<u8> {
     // Sign secret
     let secret = format!("AWS4{}", secret);
     // Sign date
-    let sign_date = hmac_sha256(secret.as_bytes(), time::format(time, DATE).as_bytes());
+    let sign_date = hmac_sha256(secret.as_bytes(), format_date(time).as_bytes());
     // Sign region
     let sign_region = hmac_sha256(sign_date.as_slice(), region.as_bytes());
     // Sign service
@@ -575,14 +571,13 @@ fn generate_signing_key(secret: &str, time: SystemTime, region: &str, service: &
 
 #[cfg(test)]
 mod tests {
-    use std::time::SystemTime;
-
     use anyhow::Result;
     use aws_sigv4;
     use aws_sigv4::http_request::{
         PayloadChecksumKind, PercentEncodingMode, SignableBody, SignableRequest, SigningSettings,
     };
     use aws_sigv4::SigningParams;
+    use std::time::SystemTime;
 
     use super::*;
 
@@ -632,7 +627,7 @@ mod tests {
             test_put_request,
         ] {
             let mut req = req_fn();
-            let now = SystemTime::now();
+            let now = time::now();
 
             let mut ss = SigningSettings::default();
             ss.percent_encoding_mode = PercentEncodingMode::Double;
@@ -643,7 +638,7 @@ mod tests {
                 .secret_key("secret_access_key")
                 .region("test")
                 .service_name("s3")
-                .time(now)
+                .time(SystemTime::from(now))
                 .settings(ss)
                 .build()
                 .expect("signing params must be valid");
@@ -678,7 +673,7 @@ mod tests {
                 .await?
                 .expect("credential must be valid");
             let actual = signer.calculate(&req, &cred)?;
-            signer.apply(&actual, &mut req).expect("must apply success");
+            signer.apply(&mut req, &actual).expect("must apply success");
 
             assert_eq!(expect_sig, actual.signature());
             assert_eq!(expect_headers, req.headers());
@@ -693,7 +688,7 @@ mod tests {
 
         for req_fn in [test_get_request, test_put_request] {
             let mut req = req_fn();
-            let now = SystemTime::now();
+            let now = time::now();
 
             let mut ss = SigningSettings::default();
             ss.percent_encoding_mode = PercentEncodingMode::Double;
@@ -705,7 +700,7 @@ mod tests {
                 .region("test")
                 .security_token("security_token")
                 .service_name("s3")
-                .time(now)
+                .time(SystemTime::from(now))
                 .settings(ss)
                 .build()
                 .expect("signing params must be valid");
@@ -741,7 +736,7 @@ mod tests {
                 .await?
                 .expect("credential must be valid");
             let actual = signer.calculate(&req, &cred)?;
-            signer.apply(&actual, &mut req).expect("must apply success");
+            signer.apply(&mut req, &actual).expect("must apply success");
 
             assert_eq!(expect_sig, actual.signature());
             assert_eq!(expect_headers, req.headers());
